@@ -33,8 +33,8 @@
 
         subroutine idmPl(entrytime,l,r,d,idm,idd,x01,x02,x12,N,P01,P02,P12,truncated,eps &
         ,maxiter0,loglik,regpar,v,converged,cv,niter,t,a01,a01_l,a01_u,a02,a02_l,a02_u,a12, &
-        a12_l,a12_u,nknots01,nknots02,nknots12,irec,kappa0,kappa,igraph,CVcrit,mdf,ti01,ti02, &
-        ti12,theta01,theta02,theta12,prt,hess_tot)
+        a12_l,a12_u,nknots01,knots01,nknots02,knots02,nknots12,knots12,irec,kappa0,kappa,&
+	conf_bands,CVcrit,mdf,theta01,theta02,theta12,prt,hess_tot)
         
         use tailles
         use propre
@@ -46,11 +46,11 @@
 
         implicit none
         
-        integer::npar,ver,nvat12,nvat02,j,k,ii,i,ic,ier,nvat01,irep,truncated,maxiter0,istop
+        integer::npar,ver,nvat12,nvat02,j,k,ii,i,ic,ier,nvat01,truncated,maxiter0,istop
         double precision::min,max,maxt1,estimv,maxt2,maxt3,mint1,mint2,mint3,ca,cb,dd,res
         double precision::mdf_int
         double precision,dimension(:),allocatable::b2
-        integer,intent(in)::P01,P12,P02,igraph,N,nknots01,nknots02,nknots12,irec,prt
+        integer,intent(in)::P01,P12,P02,N,nknots01,nknots02,nknots12,irec,prt,conf_bands
         integer,dimension(N)::idm,idd
         double precision,dimension(N)::entrytime,l,r,d
         double precision,dimension(3),intent(in)::kappa0
@@ -63,15 +63,15 @@
         double precision,dimension(p01+p02+p12),intent(out)::regpar
         double precision,dimension((p01+p02+p12)*(p01+p02+p12)),intent(out)::v
         double precision,dimension(2),intent(out)::loglik       
-        integer,intent(out)::converged,niter
-! istop
+        integer,dimension(2),intent(out)::converged
+        integer,intent(out)::niter
         double precision,dimension(99,3),intent(out)::t
         double precision,dimension(99),intent(out)::a01,a01_l,a01_u,a02,a02_l,a02_u,a12,a12_l,a12_u
         double precision,external::idmPlLikelihood
         double precision,intent(out)::CVcrit,mdf
-        double precision,dimension(nknots01+6),intent(out)::ti01
-        double precision,dimension(nknots12+6),intent(out)::ti12
-        double precision,dimension(nknots02+6),intent(out)::ti02
+        double precision,dimension(nknots01+6),intent(in)::knots01
+        double precision,dimension(nknots12+6),intent(in)::knots12
+        double precision,dimension(nknots02+6),intent(in)::knots02
         double precision,dimension(nknots01+2),intent(out)::theta01
         double precision,dimension(nknots12+2),intent(out)::theta12
         double precision,dimension(nknots02+2),intent(out)::theta02
@@ -79,6 +79,18 @@
         p01+p02+p12+nknots01+nknots12+nknots02+6),intent(out)::hess_tot
         integer,dimension(3)::noVar
 
+        nz01 = nknots01
+        nz12 = nknots12
+        nz02 = nknots02 
+
+        allocate(zi01(-2:(nz01+3)))        
+        allocate(zi02(-2:(nz02+3)))
+        allocate(zi12(-2:(nz12+3)))
+        
+        zi01 = knots01
+        zi12 = knots12
+        zi02 = knots02 
+
         if(P01.gt.0)then
         noVar(1)=0
         else
@@ -98,6 +110,7 @@
         !------------  entre parametres -----
         
         print_iter = prt
+	iconf = conf_bands
         npar = 0
         ver = 0
         pl=1
@@ -374,120 +387,6 @@
         mint1=max
 ! fin ajout
 
-        nz01 = nknots01
-        nz12 = nknots12
-        nz02 = nknots02 
-!-------------------------------------------------------------------
-        allocate(zi01(-2:(nz01+3)))
-!       write(*,*)'taille de zi01',size(zi01)
-!-------------------------------------------------------------------
-
-        zi01(-2) = mint1
-        zi01(-1) = mint1
-        zi01(0) = mint1
-        zi01(1) = mint1
-
-        do i=2,nz01-1
-                zi01(i) =zi01(i-1)+((maxt1)-mint1)/dble(nz01-1)
-        end do   
-
-        zi01(nz01) = maxt1
-        zi01(nz01+1)=maxt1
-        zi01(nz01+2)=maxt1
-        zi01(nz01+3)=maxt1
-        
-        ti01 = zi01
-
-!       write(*,*)'zi01',zi01
-
-        min = 0.d0
-        max = maxt2
-
-        do k = 1,no
-                if(t2(k).ge.min)then 
-                        if(t2(k).lt.max)then
-                        max = t2(k)
-                        endif   
-                endif
-
-                if(t3(k).ge.min)then 
-                        if(t3(k).lt.max)then
-                        max = t3(k)
-                        endif   
-                endif
-        end do   
-! ajout
-        mint2=max
-! fin ajout
-!-------------------------------------------------------------------
-        allocate(zi12(-2:(nz12+3)))
-!       write(*,*)'taille de zi12',size(zi12)
-!-------------------------------------------------------------------    
-        zi12(-2) = mint2
-        zi12(-1)= mint2
-        zi12(0)= mint2
-        zi12(1)= mint2
-
-        do i=2,nz12-1
-                zi12(i) =zi12(i-1)+((maxt2)-mint2)/dble(nz12-1) 
-        end do 
-
-        zi12(nz12) = maxt2
-        zi12(nz12+1)=maxt2
-        zi12(nz12+2)=maxt2
-        zi12(nz12+3)=maxt2
-
-        ti12 = zi12
-!       write(*,*)'zi12',zi12
-
-        min = 0.d0
-        max = maxt3
-        
-        do k = 1,no
-                if((t1(k).ge.min))then
-                        if(t1(k).lt.max)then
-                                max = t1(k)
-                        endif
-                endif
-
-                if(truncated.eq.1) then
-                        if(t0(k).ge.min)then 
-                                if(t0(k).lt.max)then
-                                        max = t0(k)
-                                endif   
-                        endif
-                end if
-
-                if(t4(k).ge.min)then 
-                        if(t4(k).lt.max)then
-                                max = t4(k)
-                        endif   
-                endif
-        end do   
-! ajout
-        mint3=max
-! fin ajout     
-!-------------------------------------------------------------------
-        allocate(zi02(-2:(nz02+3)))
-!       write(*,*)'taille de zi02',size(zi02)
-!-------------------------------------------------------------------    
-        zi02(-2) = mint3
-        zi02(-1)= mint3
-        zi02(0)= mint3
-        zi02(1)= mint3
-
-        do i=2,nz02-1
-                zi02(i) =zi02(i-1)+((maxt3)-mint3)/dble(nz02-1)
-        end do  
-
-        zi02(nz02) = maxt3      
-        zi02(nz02+1)=maxt3
-        zi02(nz02+2)=maxt3
-        zi02(nz02+3)=maxt3
-
-        ti02 = zi02
-!       write(*,*)'zi02',zi02
-
 !---------- affectation des vecteurs de splines -----------------
         
         npar  = nz01+2+nz02+2+nz12+2
@@ -559,6 +458,8 @@
         allocate(hessienne(np,np))
 !       write(*,*) '====> marquardt sans variable expli'
         call marq98(b,np,niter,v1,res,ier,istop,ca,cb,dd,idmPlLikelihood)
+        converged(1) = istop
+
 !       write(*,*) 'apres marquardt'
         
 
@@ -567,12 +468,14 @@
 
 
         if (istop.ne.1) then
-                deallocate(hessienne)
-                goto 1000
+!           deallocate(hessienne)
+           do i=1,np
+              b(i)=5.d-1
+           end do
+           ! goto 1000
         end if
 
         loglik(1)=res
-        irep = igraph
 
         ind_hess = 0    
         
@@ -619,13 +522,12 @@
 
                 call marq98(b,npar,niter,v1,res,ier,istop,ca,cb,dd,idmPlLikelihood)
                 ind_hess=0
-!               write(*,*) '====> '
-! Modif CT 4juillet2012
+                converged(2)=istop
                 if (istop.ne.1) then
                         deallocate(hessienne)
                         goto 1000
                 end if
-! Fin modif CT 4juillet2012
+
                 
 !               write(*,*)'log-vrais',res,' nb iter ',niter
                 loglik(2) = res
@@ -696,23 +598,23 @@
 !               write(*,*)nomfichregr,' fichier variables explicatives'
 !               write(*,*)' '
 
-        if(irep.eq.1)then
+!!        if(igraph.eq.1)then
                 call distance(nz01,nz02,nz12,b,t,a01,a01_l,a01_u,a02,a02_l,a02_u,a12,a12_l,a12_u)
-        end if
+!!       end if
 
         deallocate(hessienne)
-        if(irep.ne.1)then       
-                t=0.d0
-                a01=0.d0
-                a01_l=0.d0
-                a01_u=0.d0
-                a02=0.d0
-                a02_l=0.d0
-                a02_u=0.d0
-                a12=0.d0
-                a12_l=0.d0
-                a12_u=0.d0
-        end if  
+!        if(igraph.ne.1)then 
+!                t=0.d0
+!                a01=0.d0
+!                a01_l=0.d0
+!                a01_u=0.d0
+!                a02=0.d0
+!                a02_l=0.d0
+!                a02_u=0.d0
+!                a12=0.d0
+!                a12_l=0.d0
+!                a12_u=0.d0
+!        end if  
 
 !        converged = istop
         cv(1) = ca
@@ -721,7 +623,7 @@
         kappa=k0
 
 1000    continue        
-        converged = istop
+       
         deallocate(b,hes,v1)
         deallocate(t0,t1,t2,t3,t4,c,zi01,zi12,zi02,omeg01,omeg12,omeg02,&
         mm3a,mm2a,mm1a,mma,im3a,im2a,im1a,ima,mm3b,mm2b,mm1b,mmb,im3b,im2b,im1b,&
